@@ -176,9 +176,9 @@ void FileMetaDataProvider::insertSingleFileBasicData()
       }
 
       m_data.insert("kfileitem#type", item.mimeComment());
-      m_data.insert("kfileitem#modified", 
-                    format.formatRelativeDateTime(item.time(KFileItem::ModificationTime), QLocale::LongFormat));
+      m_data.insert("kfileitem#modified", item.time(KFileItem::ModificationTime));
       m_data.insert("kfileitem#owner", item.user());
+      m_data.insert("kfileitem#group", item.group());
       m_data.insert("kfileitem#permissions", item.permissionsString());
     }
 
@@ -386,6 +386,7 @@ QString FileMetaDataProvider::label(const QString& metaDataLabel) const
         { "kfileitem#comment", I18N_NOOP2_NOSTRIP("@label", "Comment") },
         { "kfileitem#modified", I18N_NOOP2_NOSTRIP("@label", "Modified") },
         { "kfileitem#owner", I18N_NOOP2_NOSTRIP("@label", "Owner") },
+        { "kfileitem#group", I18N_NOOP2_NOSTRIP("@label", "Group") },
         { "kfileitem#permissions", I18N_NOOP2_NOSTRIP("@label", "Permissions") },
         { "kfileitem#rating", I18N_NOOP2_NOSTRIP("@label", "Rating") },
         { "kfileitem#size", I18N_NOOP2_NOSTRIP("@label", "Size") },
@@ -396,13 +397,13 @@ QString FileMetaDataProvider::label(const QString& metaDataLabel) const
         { "rating", I18N_NOOP2_NOSTRIP("@label", "Rating") },
         { "userComment", I18N_NOOP2_NOSTRIP("@label", "Comment") },
         { "originUrl", I18N_NOOP2_NOSTRIP("@label", "Downloaded From") },
-        { 0, 0, 0} // Mandatory last entry
+        { nullptr, nullptr, nullptr} // Mandatory last entry
     };
 
     static QHash<QString, QString> hash;
     if (hash.isEmpty()) {
         const TranslationItem* item = &translations[0];
-        while (item->key != 0) {
+        while (item->key != nullptr) {
             hash.insert(item->key, i18nc(item->context, item->value));
             ++item;
         }
@@ -426,7 +427,8 @@ QString FileMetaDataProvider::group(const QString& label) const
         uriGrouper.insert(QLatin1String("kfileitem#totalSize"), QLatin1String("0FileItemB"));
         uriGrouper.insert(QLatin1String("kfileitem#modified"), QLatin1String("0FileItemC"));
         uriGrouper.insert(QLatin1String("kfileitem#owner"), QLatin1String("0FileItemD"));
-        uriGrouper.insert(QLatin1String("kfileitem#permissions"), QLatin1String("0FileItemE"));
+        uriGrouper.insert(QLatin1String("kfileitem#group"), QLatin1String("0FileItemE"));
+        uriGrouper.insert(QLatin1String("kfileitem#permissions"), QLatin1String("0FileItemF"));
 
         // Editable Data
         uriGrouper.insert(QLatin1String("tags"), QLatin1String("1EditableDataA"));
@@ -493,7 +495,7 @@ int FileMetaDataProvider::subDirectoriesCount(const QString& path)
     DIR* dir = ::opendir(QFile::encodeName(path));
     if (dir) {
         count = 0;
-        struct dirent *dirEntry = 0;
+        struct dirent *dirEntry = nullptr;
         while ((dirEntry = ::readdir(dir))) { // krazy:exclude=syscalls
             if (dirEntry->d_name[0] == '.') {
                 if (dirEntry->d_name[1] == '\0') {
